/*
 
Empresa desarrolladora: Junta de Andalucía

Autor: Junta de Andalucía Derechos de explotación propiedad de la Junta de Andalucía.

Éste programa es software libre: usted tiene derecho a redistribuirlo y/o modificarlo bajo los términos de la Licencia EUPL European Public License publicada por el organismo IDABC de la Comisión Europea, en su versión 1.0. o posteriores.

Éste programa se distribuye de buena fe, pero SIN NINGUNA GARANTÍA, incluso sin las presuntas garantías implícitas de USABILIDAD o ADECUACIÓN A PROPÓSITO CONCRETO. Para mas información consulte la Licencia EUPL European Public License.

Usted recibe una copia de la Licencia EUPL European Public License junto con este programa, si por algún motivo no le es posible visualizarla, puede consultarla en la siguiente URL: http://ec.europa.eu/idabc/servlets/Doc?id=31099

You should have received a copy of the EUPL European Public License along with this program. If not, see
http://ec.europa.eu/idabc/servlets/Doc?id=31096

Vous devez avoir reçu une copie de la EUPL European Public License avec ce programme. Si non, voir http://ec.europa.eu/idabc/servlets/Doc?id=30194

Sie sollten eine Kopie der EUPL European Public License zusammen mit diesem Programm. Wenn nicht, finden Sie da http://ec.europa.eu/idabc/servlets/Doc?id=29919

*/
package ${package}.dao;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

import java.util.List;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;
import org.springframework.test.context.junit4.SpringJUnit4ClassRunner;
import org.springframework.test.context.transaction.TransactionConfiguration;
import org.springframework.transaction.annotation.Transactional;

import ${package}.entidades.Libro;

@RunWith(SpringJUnit4ClassRunner.class)
@Transactional
@TransactionConfiguration(transactionManager="txManager")
@ContextConfiguration(locations={"/applicationContext.xml"})
public class LibroDAOWithJPATest{

	private LibroDAO libroDAO;

	@Autowired
	public void setRepository(LibroDAO libroDAO) {
		this.libroDAO = libroDAO;
	}
	
	@Test
	public void persistirLibro() {
		Libro libro = new Libro();
		libro.setTitulo("Scarface");
		libro.setLibros(new Integer(2));
		
		libroDAO.persist(libro);
		
		assertNotNull(libro.getId());
	}
	
	@Test
	public void shouldFindByTitle() {
		Libro libro = new Libro();
		libro.setTitulo("El Quijote");
		libro.setLibros(new Integer(1));
		
		libroDAO.persist(libro);
		assertNotNull(libro.getId());
		
		List<Libro> results = libroDAO.findByTitle("El Quijote");
		assertEquals(1, results.size());
		assertEquals("El Quijote", results.get(0).getTitulo());
	}
	
	@Test
	public void leerTodosLosLibros() {
		Libro libro1 = new Libro();
		libro1.setTitulo("El Quijote");
		libro1.setLibros(new Integer(1));
		
		Libro libro2 = new Libro();
		libro2.setTitulo("La historia interminable");
		libro2.setLibros(new Integer(1));
		
		Libro libro3 = new Libro();
		libro3.setTitulo("El nombre de la rosa");
		libro3.setLibros(new Integer(1));
		
		libroDAO.persist(libro1);
		assertNotNull(libro1.getId());
		
		libroDAO.persist(libro2);
		assertNotNull(libro2.getId());
		
		libroDAO.persist(libro3);
		assertNotNull(libro3.getId());
		
		List<Libro> results = libroDAO.loadAll();
		assertEquals(3, results.size());
	}
}
